GNU bug report logs - #63854
[PATCH] gnu: po4a: Fix SGML tests.

Previous Next

Package: guix-patches;

Reported by: gemmaro <gemmaro.dev <at> gmail.com>

Date: Fri, 2 Jun 2023 17:55:02 UTC

Severity: normal

Tags: patch

Done: Maxim Cournoyer <maxim.cournoyer <at> gmail.com>

Bug is archived. No further changes may be made.

To add a comment to this bug, you must first unarchive it, by sending
a message to control AT debbugs.gnu.org, with unarchive 63854 in the body.
You can then email your comments to 63854 AT debbugs.gnu.org in the normal way.

Toggle the display of automated, internal messages from the tracker.

View this report as an mbox folder, status mbox, maintainer mbox


Report forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Fri, 02 Jun 2023 17:55:02 GMT) Full text and rfc822 format available.

Acknowledgement sent to gemmaro <gemmaro.dev <at> gmail.com>:
New bug report received and forwarded. Copy sent to guix-patches <at> gnu.org. (Fri, 02 Jun 2023 17:55:02 GMT) Full text and rfc822 format available.

Message #5 received at submit <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: guix-patches <at> gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH] gnu: po4a: Fix SGML tests.
Date: Sat,  3 Jun 2023 02:52:56 +0900
* gnu/packages/gettext.scm (po4a): Fix SGML tests.
---
 gnu/packages/gettext.scm | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)

diff --git a/gnu/packages/gettext.scm b/gnu/packages/gettext.scm
index 9387f4fb8a5..0d66d492d40 100644
--- a/gnu/packages/gettext.scm
+++ b/gnu/packages/gettext.scm
@@ -11,7 +11,7 @@
 ;;; Copyright © 2019 Miguel <rosen644835 <at> gmail.com>
 ;;; Copyright © 2020 Jan (janneke) Nieuwenhuizen <janneke <at> gnu.org>
 ;;; Copyright © 2020 EuAndreh <eu <at> euandre.org>
-;;; Copyright © 2022 gemmaro <gemmaro.dev <at> gmail.com>
+;;; Copyright © 2022, 2023 gemmaro <gemmaro.dev <at> gmail.com>
 ;;; Copyright © 2023 Maxim Cournoyer maxim.cournoyer <at> gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -280,10 +280,11 @@ (define-public po4a
                             (wrap-program file
                               `("PERL5LIB" ":" prefix (,path))))
                           (find-files bin "\\.*$")))))
-          (add-before 'check 'disable-failing-tests
-            (lambda _
-              ;; FIXME: fails despite of importing SGMLS
-              (delete-file "t/fmt-sgml.t"))))))
+          (add-before 'check 'set-SGML-catalog-file
+            (lambda* (#:key inputs #:allow-other-keys)
+              (setenv "SGML_CATALOG_FILES"
+                      (string-append (assoc-ref inputs "docbook-sgml")
+                                     "/sgml/dtd/docbook/docbook.cat")))))))
     (native-inputs
      (list gettext-minimal
            perl-module-build
@@ -291,11 +292,13 @@ (define-public po4a
            libxml2
            libxslt
            ;; For tests.
+           docbook-sgml-4.1
            docbook-xml-4.1.2
            perl-test-pod
            texlive-tiny))
     (inputs
      (list bash-minimal
+           opensp
            perl-gettext
            perl-pod-parser
            perl-sgmls

base-commit: a7d9cd742c3149bb014db95f88d1158d590bc124
-- 
2.40.1





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Sat, 03 Jun 2023 22:13:02 GMT) Full text and rfc822 format available.

Message #8 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: Bruno Victal <mirai <at> makinata.eu>
To: gemmaro <gemmaro.dev <at> gmail.com>
Cc: 63854 <at> debbugs.gnu.org
Subject: Re: [bug#63854] [PATCH] gnu: po4a: Fix SGML tests.
Date: Sat, 3 Jun 2023 23:12:14 +0100
Hi gemmaro,

I think this is the wrong place to set the SGML_CATALOG_FILES,
based on the information in the manpage for xmllint (libxml2),
it seems that the libxml2 package should be setting this variable
through the native-search-paths instead.


-- 
Furthermore, I consider that nonfree software must be eradicated.

Cheers,
Bruno.





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Sun, 04 Jun 2023 12:30:02 GMT) Full text and rfc822 format available.

Message #11 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v2 0/2] gnu: po4a: Fix SGML tests.
Date: Sun,  4 Jun 2023 21:28:03 +0900
Hello Bruno,

> I think this is the wrong place to set the SGML_CATALOG_FILES,
> based on the information in the manpage for xmllint (libxml2),
> it seems that the libxml2 package should be setting this variable
> through the native-search-paths instead.

Thank you for the review.  I moved SGML_CATALOG_FILES from opensp to libxml2
and checked that libxml2, opensp and po4a build pass.

As with the patch series for DocBook [1], this should be core-updates since it
also triggers mass rebuilds.

[1] https://issues.guix.gnu.org/63081

Thank you again,
gemmaro.

gemmaro (2):
  gnu: libxml2: Add SGML_CATALOG_FILES to native-search-path.
  gnu: po4a: Fix SGML tests.

 gnu/packages/gettext.scm | 12 +++++-------
 gnu/packages/xml.scm     | 37 ++++++++++++++++++++-----------------
 2 files changed, 25 insertions(+), 24 deletions(-)


base-commit: b3492964c2573993b65c20f6e7d16c29cfd6f4f5
-- 
2.40.1





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Sun, 04 Jun 2023 12:30:03 GMT) Full text and rfc822 format available.

Message #14 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v2 1/2] gnu: libxml2: Add SGML_CATALOG_FILES to
 native-search-path.
Date: Sun,  4 Jun 2023 21:28:04 +0900
* gnu/packages/xml.scm
(libxml2)[native-search-paths]: Add SGML_CATALOG_FILES.
(opensp)[native-search-paths]: Remove SGML_CATALOG_FILES.
---
 gnu/packages/xml.scm | 37 ++++++++++++++++++++-----------------
 1 file changed, 20 insertions(+), 17 deletions(-)

diff --git a/gnu/packages/xml.scm b/gnu/packages/xml.scm
index 8d9974b825c..c19e7125647 100644
--- a/gnu/packages/xml.scm
+++ b/gnu/packages/xml.scm
@@ -33,6 +33,7 @@
 ;;; Copyright © 2021 Guillaume Le Vaillant <glv <at> posteo.net>
 ;;; Copyright © 2021 David Larsson <david.larsson <at> selfhosted.xyz>
 ;;; Copyright © 2021 Matthew James Kraai <kraai <at> ftbfs.org>
+;;; Copyright © 2023 gemmaro <gemmaro.dev <at> gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -222,14 +223,24 @@ (define-public libxml2
     (inputs (list xz))
     (propagated-inputs (list zlib)) ; libxml2.la says '-lz'.
     (native-inputs (list perl))
-    ;; $XML_CATALOG_FILES lists 'catalog.xml' files found in under the 'xml'
-    ;; sub-directory of any given package.
-    (native-search-paths (list (search-path-specification
-                                (variable "XML_CATALOG_FILES")
-                                (separator " ")
-                                (files '("xml"))
-                                (file-pattern "^catalog\\.xml$")
-                                (file-type 'regular))))
+    (native-search-paths
+     (list
+      ;; $XML_CATALOG_FILES lists 'catalog.xml' files found in under the 'xml'
+      ;; sub-directory of any given package.
+      (search-path-specification
+       (variable "XML_CATALOG_FILES")
+       (separator " ")
+       (files '("xml"))
+       (file-pattern "^catalog\\.xml$")
+       (file-type 'regular))
+      ;; $SGML_CATALOG_FILES lists 'catalog' or 'CATALOG' or '*.cat' files found
+      ;; under the 'sgml' sub-directory of any given package.
+      (search-path-specification
+       (variable "SGML_CATALOG_FILES")
+       (separator ":")
+       (files '("sgml"))
+       (file-pattern "^catalog$|^CATALOG$|^.*\\.cat$")
+       (file-type 'regular))))
     (search-paths native-search-paths)
     (description
      "Libxml2 is the XML C parser and toolkit developed for the Gnome
@@ -1743,7 +1754,7 @@ (define-public opensp
     (native-inputs
      (list docbook-xml-4.1.2
            docbook-xsl
-           libxml2                      ;for XML_CATALOG_DIR
+           libxml2 ;for XML_CATALOG_FILES and SGML_CATALOG_FILES
            xmlto
            ;; Dependencies to regenerate the 'configure' script.
            autoconf
@@ -1781,14 +1792,6 @@ (define-public opensp
                 (("^\tOSGMLNORM=`echo osgmlnorm\\|sed '\\$\\(transform\\)'`\\\\")
                  "\tOSGMLNORM=`echo osgmlnorm|sed '$(transform)'`")
                 (("^\t\\$\\(SHELL\\)\n") "")))))))
-    ;; $SGML_CATALOG_FILES lists 'catalog' or 'CATALOG' or '*.cat' files found
-    ;; under the 'sgml' sub-directory of any given package.
-    (native-search-paths (list (search-path-specification
-                                (variable "SGML_CATALOG_FILES")
-                                (separator ":")
-                                (files '("sgml"))
-                                (file-pattern "^catalog$|^CATALOG$|^.*\\.cat$")
-                                (file-type 'regular))))
     (home-page "https://openjade.sourceforge.net/")
     (synopsis "Suite of SGML/XML processing tools")
     (description "OpenSP is an object-oriented toolkit for SGML parsing and
-- 
2.40.1





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Sun, 04 Jun 2023 12:30:03 GMT) Full text and rfc822 format available.

Message #17 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v2 2/2] gnu: po4a: Fix SGML tests.
Date: Sun,  4 Jun 2023 21:28:05 +0900
* gnu/packages/gettext.scm (po4a)
[arguments]: Fix SGML tests.
[native-inputs]: Add docbook-sgml-4.1.
[inputs]: Add opensp.
---
 gnu/packages/gettext.scm | 12 +++++-------
 1 file changed, 5 insertions(+), 7 deletions(-)

diff --git a/gnu/packages/gettext.scm b/gnu/packages/gettext.scm
index 9387f4fb8a5..382c1d8e93e 100644
--- a/gnu/packages/gettext.scm
+++ b/gnu/packages/gettext.scm
@@ -11,7 +11,7 @@
 ;;; Copyright © 2019 Miguel <rosen644835 <at> gmail.com>
 ;;; Copyright © 2020 Jan (janneke) Nieuwenhuizen <janneke <at> gnu.org>
 ;;; Copyright © 2020 EuAndreh <eu <at> euandre.org>
-;;; Copyright © 2022 gemmaro <gemmaro.dev <at> gmail.com>
+;;; Copyright © 2022, 2023 gemmaro <gemmaro.dev <at> gmail.com>
 ;;; Copyright © 2023 Maxim Cournoyer maxim.cournoyer <at> gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -279,23 +279,21 @@ (define-public po4a
                 (for-each (lambda (file)
                             (wrap-program file
                               `("PERL5LIB" ":" prefix (,path))))
-                          (find-files bin "\\.*$")))))
-          (add-before 'check 'disable-failing-tests
-            (lambda _
-              ;; FIXME: fails despite of importing SGMLS
-              (delete-file "t/fmt-sgml.t"))))))
+                          (find-files bin "\\.*$"))))))))
     (native-inputs
      (list gettext-minimal
            perl-module-build
            docbook-xsl
-           libxml2
+           libxml2 ;for SGML_CATALOG_FILES
            libxslt
            ;; For tests.
+           docbook-sgml-4.1
            docbook-xml-4.1.2
            perl-test-pod
            texlive-tiny))
     (inputs
      (list bash-minimal
+           opensp
            perl-gettext
            perl-pod-parser
            perl-sgmls
-- 
2.40.1





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Tue, 20 Jun 2023 00:03:03 GMT) Full text and rfc822 format available.

Message #29 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v3 2/2] gnu: po4a: Fix SGML tests.
Date: Tue, 20 Jun 2023 08:47:47 +0900
* gnu/packages/gettext.scm (po4a): Fix SGML tests.
---
 gnu/packages/gettext.scm | 12 +++++-------
 1 file changed, 5 insertions(+), 7 deletions(-)

diff --git a/gnu/packages/gettext.scm b/gnu/packages/gettext.scm
index 114d8cf7afd..92bc506dd04 100644
--- a/gnu/packages/gettext.scm
+++ b/gnu/packages/gettext.scm
@@ -11,7 +11,7 @@
 ;;; Copyright © 2019 Miguel <rosen644835 <at> gmail.com>
 ;;; Copyright © 2020, 2023 Janneke Nieuwenhuizen <janneke <at> gnu.org>
 ;;; Copyright © 2020 EuAndreh <eu <at> euandre.org>
-;;; Copyright © 2022 gemmaro <gemmaro.dev <at> gmail.com>
+;;; Copyright © 2022, 2023 gemmaro <gemmaro.dev <at> gmail.com>
 ;;; Copyright © 2023 Maxim Cournoyer maxim.cournoyer <at> gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -278,23 +278,21 @@ (define-public po4a
                 (for-each (lambda (file)
                             (wrap-program file
                               `("PERL5LIB" ":" prefix (,path))))
-                          (find-files bin "\\.*$")))))
-          (add-before 'check 'disable-failing-tests
-            (lambda _
-              ;; FIXME: fails despite of importing SGMLS
-              (delete-file "t/fmt-sgml.t"))))))
+                          (find-files bin "\\.*$"))))))))
     (native-inputs
      (list gettext-minimal
            perl-module-build
            docbook-xsl
-           libxml2
+           libxml2 ;for SGML_CATALOG_FILES
            libxslt
            ;; For tests.
+           docbook-sgml-4.1
            docbook-xml-4.1.2
            perl-test-pod
            texlive-tiny))
     (inputs
      (list bash-minimal
+           opensp
            perl-gettext
            perl-pod-parser
            perl-sgmls
-- 
2.41.0





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Sat, 22 Jul 2023 14:58:02 GMT) Full text and rfc822 format available.

Message #38 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v4 2/2] gnu: po4a: Enable SGML format.
Date: Sat, 22 Jul 2023 23:56:20 +0900
* gnu/packages/gettext.scm (po4a): Enable SGML format.
[arguments]<phases>: Remove disable-failing-tests phase.
[native-inputs]: Add docbook-sgml-4.1.
[inputs]: Add opensp.
---
 gnu/packages/gettext.scm | 10 ++++------
 1 file changed, 4 insertions(+), 6 deletions(-)

diff --git a/gnu/packages/gettext.scm b/gnu/packages/gettext.scm
index b3dd844147..ca52f912e7 100644
--- a/gnu/packages/gettext.scm
+++ b/gnu/packages/gettext.scm
@@ -11,7 +11,7 @@
 ;;; Copyright © 2019 Miguel <rosen644835 <at> gmail.com>
 ;;; Copyright © 2020, 2023 Janneke Nieuwenhuizen <janneke <at> gnu.org>
 ;;; Copyright © 2020 EuAndreh <eu <at> euandre.org>
-;;; Copyright © 2022 gemmaro <gemmaro.dev <at> gmail.com>
+;;; Copyright © 2022, 2023 gemmaro <gemmaro.dev <at> gmail.com>
 ;;; Copyright © 2023 Maxim Cournoyer maxim.cournoyer <at> gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
@@ -276,10 +276,6 @@ (define-public po4a
                             (wrap-program file
                               `("PERL5LIB" ":" prefix (,path))))
                           (find-files bin "\\.*$")))))
-          (add-before 'check 'disable-failing-tests
-            (lambda _
-              ;; FIXME: fails despite of importing SGMLS
-              (delete-file "t/fmt-sgml.t")))
           #$@(if (system-hurd?)
                  #~((add-after 'unpack 'skip-tests/hurd
                       (lambda _
@@ -291,14 +287,16 @@ (define-public po4a
      (list gettext-minimal
            perl-module-build
            docbook-xsl
-           libxml2
+           libxml2 ;for SGML_CATALOG_FILES
            libxslt
            ;; For tests.
+           docbook-sgml-4.1
            docbook-xml-4.1.2
            perl-test-pod
            (texlive-updmap.cfg)))
     (inputs
      (list bash-minimal
+           opensp
            perl-gettext
            perl-pod-parser
            perl-sgmls
-- 
2.41.0





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Wed, 06 Sep 2023 14:06:01 GMT) Full text and rfc822 format available.

Message #41 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: Maxim Cournoyer <maxim.cournoyer <at> gmail.com>
To: Bruno Victal <mirai <at> makinata.eu>
Cc: gemmaro <gemmaro.dev <at> gmail.com>, 63854 <at> debbugs.gnu.org
Subject: Re: bug#63854: [PATCH] gnu: po4a: Fix SGML tests.
Date: Wed, 06 Sep 2023 10:05:10 -0400
Hi,

Bruno Victal <mirai <at> makinata.eu> writes:

> Hi gemmaro,
>
> On 2023-06-04 13:28, gemmaro wrote:
>> * gnu/packages/xml.scm
>> (libxml2)[native-search-paths]: Add SGML_CATALOG_FILES.
>> (opensp)[native-search-paths]: Remove SGML_CATALOG_FILES.
>
> […]
>
>> @@ -1781,14 +1792,6 @@ (define-public opensp
>>                  (("^\tOSGMLNORM=`echo osgmlnorm\\|sed '\\$\\(transform\\)'`\\\\")
>>                   "\tOSGMLNORM=`echo osgmlnorm|sed '$(transform)'`")
>>                  (("^\t\\$\\(SHELL\\)\n") "")))))))
>> -    ;; $SGML_CATALOG_FILES lists 'catalog' or 'CATALOG' or '*.cat' files found
>> -    ;; under the 'sgml' sub-directory of any given package.
>> -    (native-search-paths (list (search-path-specification
>> -                                (variable "SGML_CATALOG_FILES")
>> -                                (separator ":")
>> -                                (files '("sgml"))
>> -                                (file-pattern "^catalog$|^CATALOG$|^.*\\.cat$")
>> -                                (file-type 'regular))))
>
> Interesting, looking at opensp it seems that it also makes use of the
> SGML_CATALOG_FILES environment variable so I don't think it shouldn't
> be removed though I don't know if it's valid for more than one package
> to share the same native-search-path.

The search paths are not currently 'merged', but if they are exactly
defined the same way (could by via a $SGML_CATALOG_FILES export
defininition (guix search-paths)) then it should work normally.

-- 
Thanks,
Maxim




Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Wed, 06 Sep 2023 14:29:01 GMT) Full text and rfc822 format available.

Message #44 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: Bruno Victal <mirai <at> makinata.eu>
To: Maxim Cournoyer <maxim.cournoyer <at> gmail.com>
Cc: gemmaro <gemmaro.dev <at> gmail.com>, 63854 <at> debbugs.gnu.org
Subject: Re: bug#63854: [PATCH] gnu: po4a: Fix SGML tests.
Date: Wed, 6 Sep 2023 15:28:39 +0100
Hi Maxim,

On 2023-09-06 15:05, Maxim Cournoyer wrote:
>> Interesting, looking at opensp it seems that it also makes use of the
>> SGML_CATALOG_FILES environment variable so I don't think it shouldn't
>> be removed though I don't know if it's valid for more than one package
>> to share the same native-search-path.
> 
> The search paths are not currently 'merged', but if they are exactly
> defined the same way (could by via a $SGML_CATALOG_FILES export
> defininition (guix search-paths)) then it should work normally.

Indeed, this is what I'm doing in 12/61 from the #65479-v1 [1] patch
series. (hence the partial integration mentioned in the cover letter)


[1]: <https://issues.guix.gnu.org/65479>

-- 
Furthermore, I consider that nonfree software must be eradicated.

Cheers,
Bruno.




Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Wed, 06 Sep 2023 18:45:01 GMT) Full text and rfc822 format available.

Message #47 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: Maxim Cournoyer <maxim.cournoyer <at> gmail.com>
To: Bruno Victal <mirai <at> makinata.eu>
Cc: gemmaro <gemmaro.dev <at> gmail.com>, 63854 <at> debbugs.gnu.org
Subject: Re: bug#63854: [PATCH] gnu: po4a: Fix SGML tests.
Date: Wed, 06 Sep 2023 14:44:28 -0400
Hi,

Bruno Victal <mirai <at> makinata.eu> writes:

> Hi Maxim,
>
> On 2023-09-06 15:05, Maxim Cournoyer wrote:
>>> Interesting, looking at opensp it seems that it also makes use of the
>>> SGML_CATALOG_FILES environment variable so I don't think it shouldn't
>>> be removed though I don't know if it's valid for more than one package
>>> to share the same native-search-path.
>> 
>> The search paths are not currently 'merged', but if they are exactly
>> defined the same way (could by via a $SGML_CATALOG_FILES export
>> defininition (guix search-paths)) then it should work normally.
>
> Indeed, this is what I'm doing in 12/61 from the #65479-v1 [1] patch
> series. (hence the partial integration mentioned in the cover letter)
>
>
> [1]: <https://issues.guix.gnu.org/65479>

OK, excellent.

-- 
Thanks,
Maxim




Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Mon, 09 Oct 2023 22:43:02 GMT) Full text and rfc822 format available.

Message #50 received at submit <at> debbugs.gnu.org (full text, mbox):

From: Bruno Victal <mirai <at> makinata.eu>
To: guix-patches <at> gnu.org
Cc: Bruno Victal <mirai <at> makinata.eu>, gemmaro <gemmaro.dev <at> gmail.com>,
 maxim.cournoyer <at> gmail.com
Subject: [PATCH v5] gnu: po4a: Enable SGML format.
Date: Mon,  9 Oct 2023 23:20:55 +0100
From: gemmaro <gemmaro.dev <at> gmail.com>

* gnu/packages/gettext.scm (po4a): Enable SGML format.
[arguments]<phases>: Remove disable-failing-tests phase.
[native-inputs]: Add docbook-sgml-4.1. Remove libxml2.
[inputs]: Add opensp.

Modified-by: Bruno Victal <mirai <at> makinata.eu>
---

Note: Depends on v3 of <https://issues.guix.gnu.org/65479>.

 gnu/packages/gettext.scm | 7 ++-----
 1 file changed, 2 insertions(+), 5 deletions(-)

diff --git a/gnu/packages/gettext.scm b/gnu/packages/gettext.scm
index 1408cc4cb4..6e22b5a2d3 100644
--- a/gnu/packages/gettext.scm
+++ b/gnu/packages/gettext.scm
@@ -278,10 +278,6 @@ (define-public po4a
                             (wrap-program file
                               `("PERL5LIB" ":" prefix (,path))))
                           (find-files bin "\\.*$")))))
-          (add-before 'check 'disable-failing-tests
-            (lambda _
-              ;; FIXME: fails despite of importing SGMLS
-              (delete-file "t/fmt-sgml.t")))
           #$@(if (system-hurd?)
                  #~((add-after 'unpack 'skip-tests/hurd
                       (lambda _
@@ -293,14 +289,15 @@ (define-public po4a
      (list gettext-minimal
            perl-module-build
            docbook-xsl
-           libxml2
            libxslt
            ;; For tests.
+           docbook-sgml-4.1
            docbook-xml-4.1.2
            perl-test-pod
            (texlive-updmap.cfg)))
     (inputs
      (list bash-minimal
+           opensp
            perl-gettext
            perl-pod-parser
            perl-sgmls

base-commit: 24988295b7b65b4de4e9a8cc378ad13cb247ac91
-- 
2.40.1





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Thu, 08 Jun 2023 19:23:02 GMT) Full text and rfc822 format available.

Message #20 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: Bruno Victal <mirai <at> makinata.eu>
To: gemmaro <gemmaro.dev <at> gmail.com>
Cc: 63854 <at> debbugs.gnu.org
Subject: Re: [bug#63854] [PATCH core-updates v2 1/2] gnu: libxml2: Add
 SGML_CATALOG_FILES to native-search-path.
Date: Thu, 8 Jun 2023 19:46:37 +0100
Hi gemmaro,

On 2023-06-04 13:28, gemmaro wrote:
> * gnu/packages/xml.scm
> (libxml2)[native-search-paths]: Add SGML_CATALOG_FILES.
> (opensp)[native-search-paths]: Remove SGML_CATALOG_FILES.

[…]

> @@ -1781,14 +1792,6 @@ (define-public opensp
>                  (("^\tOSGMLNORM=`echo osgmlnorm\\|sed '\\$\\(transform\\)'`\\\\")
>                   "\tOSGMLNORM=`echo osgmlnorm|sed '$(transform)'`")
>                  (("^\t\\$\\(SHELL\\)\n") "")))))))
> -    ;; $SGML_CATALOG_FILES lists 'catalog' or 'CATALOG' or '*.cat' files found
> -    ;; under the 'sgml' sub-directory of any given package.
> -    (native-search-paths (list (search-path-specification
> -                                (variable "SGML_CATALOG_FILES")
> -                                (separator ":")
> -                                (files '("sgml"))
> -                                (file-pattern "^catalog$|^CATALOG$|^.*\\.cat$")
> -                                (file-type 'regular))))

Interesting, looking at opensp it seems that it also makes use of the
SGML_CATALOG_FILES environment variable so I don't think it shouldn't
be removed though I don't know if it's valid for more than one package
to share the same native-search-path.

Maybe someone else can weigh in?


-- 
Furthermore, I consider that nonfree software must be eradicated.

Cheers,
Bruno.





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Tue, 20 Jun 2023 00:03:02 GMT) Full text and rfc822 format available.

Message #23 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v3 0/2] gnu: po4a: Fix SGML tests.
Date: Tue, 20 Jun 2023 08:47:45 +0900
Hello Bruno,

Bruno Victal <mirai <at> makinata.eu> writes:
>> @@ -1781,14 +1792,6 @@ (define-public opensp
>>                  (("^\tOSGMLNORM=`echo osgmlnorm\\|sed '\\$\\(transform\\)'`\\\\")
>>                   "\tOSGMLNORM=`echo osgmlnorm|sed '$(transform)'`")
>>                  (("^\t\\$\\(SHELL\\)\n") "")))))))
>> -    ;; $SGML_CATALOG_FILES lists 'catalog' or 'CATALOG' or '*.cat' files found
>> -    ;; under the 'sgml' sub-directory of any given package.
>> -    (native-search-paths (list (search-path-specification
>> -                                (variable "SGML_CATALOG_FILES")
>> -                                (separator ":")
>> -                                (files '("sgml"))
>> -                                (file-pattern "^catalog$|^CATALOG$|^.*\\.cat$")
>> -                                (file-type 'regular))))
>
> Interesting, looking at opensp it seems that it also makes use of the
> SGML_CATALOG_FILES environment variable so I don't think it shouldn't
> be removed though I don't know if it's valid for more than one package
> to share the same native-search-path.

You are right.  Looking at other packages, there are some
native-search-paths defined with the same name, such as
C_INCLUDE_PATH.  One solution to avoid duplication is to define it
globally, like $SSL_CERT_DIR in guix/search-paths.scm, but maybe not
go that far this time.  I stopped changing opensp.

Best,
gemmaro.

gemmaro (2):
  gnu: libxml2: Add SGML_CATALOG_FILES to native-search-path.
  gnu: po4a: Fix SGML tests.

 gnu/packages/gettext.scm | 12 +++++-------
 gnu/packages/xml.scm     | 27 +++++++++++++++++++--------
 2 files changed, 24 insertions(+), 15 deletions(-)


base-commit: d884fc9e2efecfba09af4694f5a13ad7fc6f704f
-- 
2.40.1





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Tue, 20 Jun 2023 00:03:02 GMT) Full text and rfc822 format available.

Message #26 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v3 1/2] gnu: libxml2: Add SGML_CATALOG_FILES to
 native-search-path.
Date: Tue, 20 Jun 2023 08:47:46 +0900
* gnu/packages/xml.scm (libxml2)[native-search-paths]: Add SGML_CATALOG_FILES.
---
 gnu/packages/xml.scm | 27 +++++++++++++++++++--------
 1 file changed, 19 insertions(+), 8 deletions(-)

diff --git a/gnu/packages/xml.scm b/gnu/packages/xml.scm
index 8d9974b825c..e376f0f09b2 100644
--- a/gnu/packages/xml.scm
+++ b/gnu/packages/xml.scm
@@ -33,6 +33,7 @@
 ;;; Copyright © 2021 Guillaume Le Vaillant <glv <at> posteo.net>
 ;;; Copyright © 2021 David Larsson <david.larsson <at> selfhosted.xyz>
 ;;; Copyright © 2021 Matthew James Kraai <kraai <at> ftbfs.org>
+;;; Copyright © 2023 gemmaro <gemmaro.dev <at> gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -222,14 +223,24 @@ (define-public libxml2
     (inputs (list xz))
     (propagated-inputs (list zlib)) ; libxml2.la says '-lz'.
     (native-inputs (list perl))
-    ;; $XML_CATALOG_FILES lists 'catalog.xml' files found in under the 'xml'
-    ;; sub-directory of any given package.
-    (native-search-paths (list (search-path-specification
-                                (variable "XML_CATALOG_FILES")
-                                (separator " ")
-                                (files '("xml"))
-                                (file-pattern "^catalog\\.xml$")
-                                (file-type 'regular))))
+    (native-search-paths
+     (list
+      ;; $XML_CATALOG_FILES lists 'catalog.xml' files found in under the 'xml'
+      ;; sub-directory of any given package.
+      (search-path-specification
+       (variable "XML_CATALOG_FILES")
+       (separator " ")
+       (files '("xml"))
+       (file-pattern "^catalog\\.xml$")
+       (file-type 'regular))
+      ;; $SGML_CATALOG_FILES lists 'catalog' or 'CATALOG' or '*.cat' files found
+      ;; under the 'sgml' sub-directory of any given package.
+      (search-path-specification
+       (variable "SGML_CATALOG_FILES")
+       (separator ":")
+       (files '("sgml"))
+       (file-pattern "^catalog$|^CATALOG$|^.*\\.cat$")
+       (file-type 'regular))))
     (search-paths native-search-paths)
     (description
      "Libxml2 is the XML C parser and toolkit developed for the Gnome
-- 
2.40.1





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Sat, 22 Jul 2023 14:58:01 GMT) Full text and rfc822 format available.

Message #32 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v4 0/2] gnu: po4a: Enable SGML format.
Date: Sat, 22 Jul 2023 23:56:18 +0900
I rebased on top of current master.

gemmaro (2):
  gnu: libxml2: Add SGML_CATALOG_FILES to native-search-path.
  gnu: po4a: Fix SGML tests.

 gnu/packages/gettext.scm | 10 ++++------
 gnu/packages/xml.scm     | 27 +++++++++++++++++++--------
 2 files changed, 23 insertions(+), 14 deletions(-)


base-commit: eb12f3fd8bee99920118ec802ffbac8f1ab676b9
-- 
2.41.0





Information forwarded to guix-patches <at> gnu.org:
bug#63854; Package guix-patches. (Sat, 22 Jul 2023 14:58:02 GMT) Full text and rfc822 format available.

Message #35 received at 63854 <at> debbugs.gnu.org (full text, mbox):

From: gemmaro <gemmaro.dev <at> gmail.com>
To: 63854 <at> debbugs.gnu.org
Cc: gemmaro <gemmaro.dev <at> gmail.com>
Subject: [PATCH core-updates v4 1/2] gnu: libxml2: Add SGML_CATALOG_FILES to
 native-search-path.
Date: Sat, 22 Jul 2023 23:56:19 +0900
* gnu/packages/xml.scm (libxml2)[native-search-paths]: Add SGML_CATALOG_FILES.
---
 gnu/packages/xml.scm | 27 +++++++++++++++++++--------
 1 file changed, 19 insertions(+), 8 deletions(-)

diff --git a/gnu/packages/xml.scm b/gnu/packages/xml.scm
index 555f0ab624..712af965d8 100644
--- a/gnu/packages/xml.scm
+++ b/gnu/packages/xml.scm
@@ -33,6 +33,7 @@
 ;;; Copyright © 2021 Guillaume Le Vaillant <glv <at> posteo.net>
 ;;; Copyright © 2021 David Larsson <david.larsson <at> selfhosted.xyz>
 ;;; Copyright © 2021 Matthew James Kraai <kraai <at> ftbfs.org>
+;;; Copyright © 2023 gemmaro <gemmaro.dev <at> gmail.com>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -222,14 +223,24 @@ (define-public libxml2
     (inputs (list xz))
     (propagated-inputs (list zlib)) ; libxml2.la says '-lz'.
     (native-inputs (list perl))
-    ;; $XML_CATALOG_FILES lists 'catalog.xml' files found in under the 'xml'
-    ;; sub-directory of any given package.
-    (native-search-paths (list (search-path-specification
-                                (variable "XML_CATALOG_FILES")
-                                (separator " ")
-                                (files '("xml"))
-                                (file-pattern "^catalog\\.xml$")
-                                (file-type 'regular))))
+    (native-search-paths
+     (list
+      ;; $XML_CATALOG_FILES lists 'catalog.xml' files found in under the 'xml'
+      ;; sub-directory of any given package.
+      (search-path-specification
+       (variable "XML_CATALOG_FILES")
+       (separator " ")
+       (files '("xml"))
+       (file-pattern "^catalog\\.xml$")
+       (file-type 'regular))
+      ;; $SGML_CATALOG_FILES lists 'catalog' or 'CATALOG' or '*.cat' files found
+      ;; under the 'sgml' sub-directory of any given package.
+      (search-path-specification
+       (variable "SGML_CATALOG_FILES")
+       (separator ":")
+       (files '("sgml"))
+       (file-pattern "^catalog$|^CATALOG$|^.*\\.cat$")
+       (file-type 'regular))))
     (search-paths native-search-paths)
     (description
      "Libxml2 is the XML C parser and toolkit developed for the Gnome
-- 
2.41.0





Reply sent to Maxim Cournoyer <maxim.cournoyer <at> gmail.com>:
You have taken responsibility. (Wed, 11 Oct 2023 01:53:07 GMT) Full text and rfc822 format available.

Notification sent to gemmaro <gemmaro.dev <at> gmail.com>:
bug acknowledged by developer. (Wed, 11 Oct 2023 01:53:08 GMT) Full text and rfc822 format available.

Message #55 received at 63854-done <at> debbugs.gnu.org (full text, mbox):

From: Maxim Cournoyer <maxim.cournoyer <at> gmail.com>
To: Bruno Victal <mirai <at> makinata.eu>
Cc: 63854-done <at> debbugs.gnu.org, gemmaro <gemmaro.dev <at> gmail.com>
Subject: Re: [bug#63854] [PATCH v5] gnu: po4a: Enable SGML format.
Date: Tue, 10 Oct 2023 21:52:03 -0400
Hi,

Bruno Victal <mirai <at> makinata.eu> writes:

> From: gemmaro <gemmaro.dev <at> gmail.com>
>
> * gnu/packages/gettext.scm (po4a): Enable SGML format.
> [arguments]<phases>: Remove disable-failing-tests phase.
> [native-inputs]: Add docbook-sgml-4.1. Remove libxml2.
> [inputs]: Add opensp.

Installed to core-updates; thanks!

-- 
Thanks,
Maxim




bug archived. Request was from Debbugs Internal Request <help-debbugs <at> gnu.org> to internal_control <at> debbugs.gnu.org. (Wed, 08 Nov 2023 12:24:09 GMT) Full text and rfc822 format available.

This bug report was last modified 163 days ago.

Previous Next


GNU bug tracking system
Copyright (C) 1999 Darren O. Benham, 1997,2003 nCipher Corporation Ltd, 1994-97 Ian Jackson.